summaryrefslogtreecommitdiffstats
path: root/src/lib
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/krb5/krb/ChangeLog7
-rw-r--r--src/lib/krb5/krb/init_ctx.c14
2 files changed, 15 insertions, 6 deletions
diff --git a/src/lib/krb5/krb/ChangeLog b/src/lib/krb5/krb/ChangeLog
index 18bf885944..00c7d361f3 100644
--- a/src/lib/krb5/krb/ChangeLog
+++ b/src/lib/krb5/krb/ChangeLog
@@ -1,3 +1,10 @@
+Sat Dec 21 01:26:11 1996 Theodore Y. Ts'o <tytso@mit.edu>
+
+ * init_ctx.c (krb5_init_context): Use new call krb5_vercheck() for
+ Windows timebomb checking; this call returns an error
+ code, which is returned to the user if the timebomb should
+ be activated.
+
Thu Nov 21 13:54:01 1996 Ezra Peisach <epeisach@mit.edu>
* recvauth.c (krb5_recvauth): If there is an error, and the server
diff --git a/src/lib/krb5/krb/init_ctx.c b/src/lib/krb5/krb/init_ctx.c
index 19aaf66424..2794fbcf65 100644
--- a/src/lib/krb5/krb/init_ctx.c
+++ b/src/lib/krb5/krb/init_ctx.c
@@ -27,7 +27,7 @@
#include <ctype.h>
#if (defined(_MSDOS) || defined(_WIN32))
-extern void krb5_win_do_init();
+extern krb5_error_code krb5_vercheck();
#endif
krb5_error_code INTERFACE
@@ -38,12 +38,17 @@ krb5_init_context(context)
krb5_error_code retval;
int tmp;
+ /* Initialize error tables */
+ krb5_init_ets(ctx);
+
#if (defined(_MSDOS) || defined(_WIN32))
/*
* krb5_win_do_init() is defined in win_glue.c, and this is
* where we handle the timebomb and version server checks.
*/
- krb5_win_do_init();
+ retval = krb5_vercheck();
+ if (retval)
+ return retval;
#endif
*context = 0;
@@ -54,9 +59,6 @@ krb5_init_context(context)
memset(ctx, 0, sizeof(struct _krb5_context));
ctx->magic = KV5M_CONTEXT;
- /* Initialize error tables */
- krb5_init_ets(ctx);
-
/* Set the default encryption types, possible defined in krb5/conf */
if ((retval = krb5_set_default_in_tkt_ktypes(ctx, NULL)))
goto cleanup;
@@ -38,12 +38,17 @@ krb5_init_context(context)
#if (defined(_MSDOS) || defined(_WIN32))
/*
- * krb5_win_do_init() is defined in win_glue.c, and this is
+ * krb5_vercheck() is defined in win_glue.c, and this is
* where we handle the timebomb and version server checks.
*/